@@ -1,10 +1,14 @@
-"""Package for scripting the Nansurf control software.
+"""Package for scripting the Nanosurf control software.
 Copyright (C) Nanosurf AG - All Rights Reserved (2021)
 License - MIT"""
 
+import os
+import pathlib
+from nanosurf._version import __version__
 from nanosurf.lib.spm import *
 from nanosurf.lib.spm.studio import *
 
+
 class Studio(StudioScriptSession):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -45,3 +49,29 @@ class SPM_S(Spm):
     def __init__(self, *args, **kwargs):
         super().__init__("SPM_S.Application", *args, **kwargs)
 
+def package_path() -> pathlib.Path:
+    return pathlib.Path(os.path.dirname(os.path.abspath(__file__)))
+
+def doc_path() -> pathlib.Path:
+    return package_path() / "doc"
+
+def lib_path() -> pathlib.Path:
+    return package_path() / "lib"
+
+def app_path() -> pathlib.Path:
+    return package_path() / "app"
+
+def help(): 
+    print("Nanosurf python script package:")
+    print("-------------------------------")
+    print(f"Installed version: {__version__}")
+    print("\nThe library documentation is here:")
+    print(doc_path())
+    for doc in os.listdir(doc_path()):
+        print(f"  {doc}")
+    print("\nThe demos and apps are stored here:")
+    print(app_path())
+    for demo in os.listdir(app_path()):
+        print(f"  {demo}")
+
+
